@@ -1,16 +1,16 @@
 import requests
 import json
 import time
+import os
 
 class quantum_lab():
 
     def __init__(self,
-            userID: str, 
             resourceId: int,
             volumeName: str, 
             resourceName: str
         ):
-        self.userID = userID
+        self.userID = os.environ["QCC_USER_ID"]
         # self.uploadType = uploadType
         # self.shot = shot
         self.resourceId = resourceId
@@ -34,7 +34,7 @@ class quantum_lab():
             filePath: str, 
             timeout = 120
         ):
-        url = "http://sdt-api.qcc.svc.cluster.local"
+        url = "http://job-management.qcc.svc.cluster.local"
         url_path = f"{url}/qcc/notebook/job"
 
         headers = {
