@@ -7,7 +7,7 @@ def error_handler(resource):
     return {response.json()['error']}
 
 def getResource():
-    url = "http://sdt-api.qcc.svc.cluster.local"
+    url = "http://job-management.qcc.svc.cluster.local"
     url_path = f"{url}/qcc/resources"
 
     response = requests.get(f"{url_path}") # , params=params)
